@@ -24,7 +24,7 @@ class ManualReuseExplorer(RandomMotorExplorer):
 
     def _explore(self):
         try:
-            m_signal = self.m_signals.next()
+            m_signal = next(self.m_signals)
             return {'m_signal': m_signal}
         except StopIteration:
             return None
